=====================================
toll — poor man's integration testing
=====================================

.. image:: https://travis-ci.org/icemac/toll.svg?branch=master

toll = **t**\ est **o**\ ffline **l**\ ocally **l**\ ightweight

Run the tests of multiple configured packages:

* right one package after another

* stopping with the first package which has a failing test

This package is compatible with Python 2.7, 3.3, 3.4, 3.5, 3.6 and PyPy2.

Documentation see: http://toll.readthedocs.io

This package is licensed under the MIT License, see LICENSE.txt inside the
package.
